/*
** Module   : BufferField.java
** Abstract : interface which must be extended by a buffer field implementation class
**
** Copyright (c) 2013-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 VMN 20130207 Created initial version.
** 002 VMN 20130217 Extended from DatabaseInfo and added support for attributes
**                  BUFFER-NAME (KW_BUF_NAME),
**                  LITERAL-QUESTION (KW_LIT_QSTN)
**                  VALIDATE-MESSAGE (KW_VAL_MSG)
**                  MANDATORY (KW_MAND)
**                  VALIDATE-EXPRESSION (KW_VAL_EXPR)
** 003 VMN 20130219 Added support for attributes
**                  POSITION (KW_POS)
** 004 CA  20130221 Added support for ADM-DATA, UNIQUE-ID. Moved FORMAT and COLUMN-LABEL in the
**                  CommonField interface. 
** 005 OM  20130221 Switched data type for BUFFER-VALUE to BaseDataType instead of Object.
** 006 OM  20130304 Added missing overloaded method for value().
** 007 CA  20130315 Added missing API for STRING-VALUE.
** 008 ECF 20130417 Moved initial() method from Buffer.
** 009 CA  20130927          Added LegacyResource annotation, to determine resource type.
** 010 EVL 20130911 Adding legacy attributes and methods annotation.
** 011 ECF 20150315 Renamed from FieldInterface.
** 012 SVL 20150503 Added bufferHandle.
*/

package com.goldencode.p2j.persist;

import com.goldencode.p2j.util.*;

/**
 * Defines the public API for services representing Progress builtin functions, methods,
 * attributes, and language statements, which operate on fields.
 */
@LegacyResource(resource = LegacyResource.BUFFER_FIELD)
public interface BufferField
extends DatabaseInfo,
        Sizeable,
        WrappedResource,
        CommonField,
        ADMData,
        UniqueID
{
   /**
    * Conversion of EXTENT attribute (KW_EXTENT).
    *
    * Getter of EXTENT attribute
    *
    */
   @LegacyAttribute(name = "EXTENT")
   public integer extent();

   /**
    * Conversion of STRING-VALUE attribute (KW_STR_VAL).
    *
    * Getter of STRING-VALUE attribute.
    *
    * @return  current value of STRING-VALUE attribute.
    */
   @LegacyMethod(name = "STRING-VALUE")
   public character stringValue();

   /**
    * Conversion of STRING-VALUE attribute (KW_STR_VAL).
    *
    * Getter of STRING-VALUE attribute.
    *
    * @param   index
    *          An integer expression representing a subscript, for fields that have extents.
    *
    * @return  current value of STRING-VALUE attribute.
    */
   @LegacyMethod(name = "STRING-VALUE")
   public character stringValue(int index);

   /**
    * Conversion of STRING-VALUE attribute (KW_STR_VAL).
    *
    * Getter of STRING-VALUE attribute.
    *
    * @param    index
    *           An integer expression representing a subscript, for fields that have extents.
    *
    * @return   current value of STRING-VALUE attribute.
    */
   @LegacyMethod(name = "STRING-VALUE")
   public character stringValue(NumberType index);

   /**
    * Conversion of BUFFER-VALUE attribute (KW_BUF_VAL).
    *
    * Getter of current value of a buffer-field object. If you modify the BUFFER-VALUE attribute,
    * Progress sets the buffer-field object to the new value.
    *
    * @param   index
    *          An INTEGER expression representing a subscript, for fields that have extents.
    *
    * @return  current value of a buffer-field object.
    */
   @LegacyAttribute(name = "BUFFER-VALUE")
   public BaseDataType value(int index);

   /**
    * Conversion of BUFFER-VALUE attribute (KW_BUF_VAL).
    *
    * Getter of current value of a buffer-field object. If you modify the BUFFER-VALUE attribute,
    * Progress sets the buffer-field object to the new value.
    *
    * @param   index
    *          An INTEGER expression representing a subscript, for fields that have extents.
    *
    * @return  current value of a buffer-field object.
    */
   @LegacyAttribute(name = "BUFFER-VALUE")
   public BaseDataType value(NumberType index);

   /**
    * Conversion of BUFFER-VALUE attribute (KW_BUF_VAL).
    *
    * Setter of current value of a buffer-field object. If you modify the BUFFER-VALUE attribute,
    * Progress sets the buffer-field object to the new value.
    *
    * @param   index
    *          An INTEGER expression representing a subscript, for fields that have extents.
    * @param   newValue
    *          New value of a buffer-field object.
    *
    */
   @LegacyAttribute(name = "BUFFER-VALUE", setter = true)
   public void changeValue(int index, Object newValue);

   /**
    * Conversion of BUFFER-VALUE attribute (KW_BUF_VAL).
    *
    * Setter of current value of a buffer-field object. If you modify the BUFFER-VALUE attribute,
    * Progress sets the buffer-field object to the new value.
    *
    * @param   index
    *          An INTEGER expression representing a subscript, for fields that have extents.
    * @param   newValue
    *          New value of a buffer-field object.
    *
    */
   @LegacyAttribute(name = "BUFFER-VALUE", setter = true)
   public void changeValue(NumberType index, Object newValue);

   /**
    * Conversion of BUFFER-VALUE attribute (KW_BUF_VAL).
    *
    * Getter of current value of a buffer-field object. If you modify the BUFFER-VALUE attribute,
    * Progress sets the buffer-field object to the new value.
    *
    * @return  current value of a buffer-field object.
    */
   @LegacyAttribute(name = "BUFFER-VALUE")
   public BaseDataType value();

   /**
    * Conversion of BUFFER-VALUE attribute (KW_BUF_VAL).
    *
    * Setter of current value of a buffer-field object. If you modify the BUFFER-VALUE attribute,
    * Progress sets the buffer-field object to the new value.
    *
    * @param   newValue
    *          New value of a buffer-field object.
    *
    */
   @LegacyAttribute(name = "BUFFER-VALUE", setter = true)
   public void changeValue(Object newValue);

   /**
    * Conversion of BUFFER-NAME attribute (KW_BUF_NAME).
    *
    * Gets the name of the buffer object to which the buffer-field object belongs.
    *
    * @return  name of the buffer object to which the buffer-field object belongs.
    */
   @LegacyAttribute(name = "BUFFER-NAME")
   public character bufferName();

   /**
    * Returns the handle of the buffer object to which the buffer-field belongs.
    *
    * @return the handle of the buffer object to which the buffer-field belongs.
    */
   @LegacyAttribute(name = "BUFFER-HANDLE")
   public handle bufferHandle();

   /**
    * Conversion of INITIAL attribute (KW_INIT).
    *
    * Getter of INITIAL attribute.
    *
    * @return  Current value of INITIAL attribute.
    */
   @LegacyAttribute(name = "INITIAL")
   public character initial();

   /**
    * Conversion of LITERAL-QUESTION attribute (KW_LIT_QSTN).
    *
    * Getter of LITERAL-QUESTION attribute.
    *
    * @return  current value of LITERAL-QUESTION attribute.
    */
   @LegacyAttribute(name = "LITERAL-QUESTION")
   public logical literalQuestion();

   /**
    * Conversion of LITERAL-QUESTION attribute (KW_LIT_QSTN).
    *
    * Setter of LITERAL-QUESTION attribute.
    *
    * @param   literalQuestion
    *          New value of LITERAL-QUESTION attribute.
    */
   @LegacyAttribute(name = "LITERAL-QUESTION", setter = true)
   public void changeLiteralQuestion(logical literalQuestion);

   /**
    * Conversion of VALIDATE-MESSAGE attribute (KW_VAL_MSG).
    *
    * Getter of VALIDATE-MESSAGE attribute.
    *
    * @return  current value of VALIDATE-MESSAGE attribute.
    */
   @LegacyAttribute(name = "VALIDATE-MESSAGE")
   public character validateMessage();

   /**
    * Conversion of VALIDATE-MESSAGE attribute (KW_VAL_MSG).
    *
    * Setter of VALIDATE-MESSAGE attribute.
    *
    * @param   validateMessage
    *          New value of VALIDATE-MESSAGE attribute.
    */
   @LegacyAttribute(name = "VALIDATE-MESSAGE", setter = true)
   public void changeValidateMessage(character validateMessage);

   /**
    * Conversion of MANDATORY attribute (KW_MAND).
    *
    * Getter of KW_MAND attribute.
    *
    * @return current value of KW_MAND attribute.
    */
   @LegacyAttribute(name = "MANDATORY")
   public logical mandatory();

   /**
    * Conversion of VALIDATE-EXPRESSION attribute (KW_VAL_EXPR).
    *
    * Getter of VALIDATE-EXPRESSION attribute.
    *
    * @return current value of VALIDATE-EXPRESSION attribute.
    */
   @LegacyAttribute(name = "VALIDATE-EXPRESSION")
   public character validateExpression();

   /**
    * Conversion of VALIDATE-EXPRESSION attribute (KW_VAL_EXPR).
    *
    * Setter of VALIDATE-EXPRESSION attribute.
    *
    * @param  validateExpression
    *         New value of VALIDATE-EXPRESSION attribute.
    */
   @LegacyAttribute(name = "VALIDATE-EXPRESSION", setter = true)
   public void changeValidateExpression(character validateExpression);

   /**
    * Conversion of POSITION attribute (KW_POS).
    *
    * Getter of POSITION attribute.
    *
    * @return current value of POSITION attribute.
    */
   @LegacyAttribute(name = "POSITION")
   public integer position();
}
